Learn R Programming

ggguides (version 1.1.4)

ggguides-package: ggguides: Simplified Legend and Guide Alignment for 'ggplot2'

Description

Provides one-liner functions for common legend and guide operations in 'ggplot2'. Simplifies legend positioning, styling, wrapping, and collection across multi-panel plots created with 'patchwork' or 'cowplot'.

Arguments

Author

Maintainer: Gilles Colling gilles.colling051@gmail.com

See Also